Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/srunx/cli/main.py | 249 | 87 | 2 | 65%
src/srunx/cli/workflow.py | 89 | 3 | 2 | 97%
src/srunx/client.py | 134 | 17 | 0 | 87%
src/srunx/logging.py | 26 | 17 | 0 | 35%
src/srunx/models.py | 113 | 24 | 0 | 79%
src/srunx/utils.py | 25 | 20 | 0 | 20%
src/srunx/workflows/runner.py | 75 | 1 | 0 | 99%
src/srunx/workflows/tasks.py | 30 | 0 | 0 | 100%
Total | 741 | 169 | 4 | 77%

No items found using the specified filter.